==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/admin/messages/nl/settings.php <==
<?php

return [
    '1 month' => '1 maand',
    '1 week' => '1 week',
    '1 year' => '1 jaar',
    '2 weeks' => 'twee weken',
    '3 months' => 'drie maanden',
    '6 months' => 'zes maanden',
    '<strong>Confirm</strong> icon deletion' => '<strong>Bevestig</strong> de verwijdering van het pictogram',
    '<strong>Confirm</strong> image deletion' => '<strong>Bevestig</strong> de verwijdering van de afbeelding',
    '<strong>Maintenance</strong> Mode' => '<strong>Onderhoudsmodus</strong>',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>Waarschuwing:</strong> alle gebruikers worden onmiddellijk uitgelogd, behalve beheerders.',
    'APC(u)' => 'APC(u)',
    'Activate' => 'Activeren',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => 'Onderhoudsmodus activeren en toegang tot het platform uitschakelen voor niet-beheerders?<br><br>',
    'Add OEmbed provider' => 'OEmbed provider toevoegen',
    'Add custom info text for maintenance mode. Displayed on the login page.' => 'Voeg aangepaste informatietekst toe voor de onderhoudsmodus. Weergegeven op de inlogpagina.',
    'Add new provider' => 'Nieuwe provider toevoegen',
    'Advanced Settings' => 'Geavanceerde Instellingen',
    'Allow Self-Signed Certificates?' => 'Sta zelfondertekende certificaten toe?',
    'Allowed file extensions' => 'Toegestane bestandsextensies',
    'Alphabetical' => 'Alfabetisch',
    'Appearance Settings' => 'Weergave instellingen',
    'Auto format based on user language - Example: {example}' => 'Automatisch indeling gebaseerd op de gebruikerstaal - Voorbeeld: {example}',
    'Back to overview' => 'Terug naar het overzicht',
    'Base URL' => 'Basis-URL',
    'Cache Backend' => 'Cache Backend',
    'Comma separated list. Leave empty to allow all.' => 'Lijst gescheiden door komma\'s. Laat leeg om alles toe te staan.',
    'Could not send test email.' => 'Kan test-e-mail niet verzenden.',
    'Currently no provider active!' => 'Geen enkele provider is ingeschakeld!',
    'Currently there are {count} records in the database dating from {dating}.' => 'Momenteel zijn er {count} records in de gegevensbank vanaf {dating}.',
    'Dashboard' => 'Dashboard',
    'Date input format' => 'Datum invoerformaat',
    'Deactivate' => 'Deactiveren',
    'Deactivate maintenance mode and enable all users to access the platform again?' => 'Onderhoudsmodus deactiveren en alle gebruikers weer toegang geven?',
    'Default Expire Time (in seconds)' => 'Standaard vervaltijd (in seconden)',
    'Default Timezone' => 'Standaard tijdzone',
    'Default language' => 'Standaard taal',
    'Default pagination size (Entries per page)' => 'Standaard paginering grootte (Berichten per pagina)',
    'Default stream content order' => 'Standaard inhoud volgorde',
    'Delete' => 'Verwijder',
    'Display Name (Format)' => 'Weergavenaam (Formaat)',
    'Dropdown space order' => 'Keuzelijst ruimte volgorde',
    'E-Mail' => 'E-mail',
    'E-Mail reply-to' => 'Antwoord naar e-mail adres',
    'E-Mail sender address' => 'E-mailadres afzender',
    'E-Mail sender name' => 'Naam van afzender',
    'E.g. http://example.com/humhub' => 'Voorbeeld http://example.com/humhub',
    'Edit OEmbed provider' => 'OEmbed provider aanpassen',
    'Enable maintenance mode' => 'Onderhoudsmodus inschakelen',
    'Enable user friendship system' => 'Vriendschap systeem inschakelen',
    'Enabled' => 'Ingeschakeld',
    'Enabled OEmbed providers' => 'Ingeschakelde OEmbed providers',
    'Encryption' => 'Encryptie',
    'Endpoint Url' => 'Eindpunt URL',
    'Exclude media files from stream attachment list' => 'Mediabestanden niet opnemen in de lijst met berichtenbijlagen',
    'File' => 'Bestand',
    'Firstname Lastname (e.g. John Doe)' => 'Voornaam Achternaam (bijvoorbeeld Jan Jansen)',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Vaste indeling (dd/mm/jjjj) - Bijvoorbeeld: {example}',
    'Friendship' => 'Vriendschap',
    'General' => 'Algemeen',
    'General Settings' => 'Algemene instellingen',
    'HTML tracking code' => 'HTML tracking code',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Hieronder past u de registratie en aanvullende gebruiker instellingen van uw website aan.',
    'Here you can configure basic settings of your social network.' => 'Hieronder verandert u de basis instellingen van uw website.',
    'Horizontal scrolling images on a mobile device' => 'Beelden horizontaal scrollen op een mobiel apparaat',
    'Icon upload' => 'Pictogram upload',
    'Last visit' => 'Laatste bezoek',
    'Logo upload' => 'Logo upload',
    'Mail Transport Type' => 'Mail transporttype',
    'Maintenance mode' => 'Onderhoudsmodus',
    'Maximum allowed age for logs.' => 'Maximaal leeftijd van logs.',
    'Maximum upload file size (in MB)' => 'Maximale bestandsgrootte (in MB\'s)',
    'Mobile appearance' => 'Mobiel uiterlijk',
    'Name of the application' => 'Naam van de applicatie',
    'No Proxy Hosts' => 'Geen Proxy Hosts',
    'No caching' => 'Geen caching',
    'Notification Settings' => 'Meldingen instellingen',
    'Old logs can significantly increase the size of your database while providing little information.' => 'Oude logs nemen veel ruimte in, maar leveren weinig informatie op.',
    'Optional. Default reply address for system emails like notifications.' => 'Optioneel. Standaard antwoordadres voor systeem-e-mails zoals meldingen.',
    'PHP APC(u) Extension missing - Type not available!' => 'De PHP APC(u) extensie ontbreekt - Type is niet beschikbaar!',
    'PHP reported a maximum of {maxUploadSize} MB' => 'PHP meld een maximum van {maxUploadSize} MB',
    'Password' => 'Wachtwoord',
    'Port' => 'Poort',
    'Port number' => 'Poortnummer',
    'Prevent client caching of following scripts' => 'Voorkom dat client-caching de volgende scripts bevat',
    'Redis' => 'Redis',
    'Reported database time: {dateTime}' => 'Gemelde gegevensbanktijd: {dateTime}',
    'SMTP Options' => 'SMTP opties',
    'Save' => 'Bewaar',
    'Save & Flush Caches' => 'Bewaar &amp; vernieuw de caches',
    'Save & Test' => 'Bewaar &amp; Test',
    'Saved' => 'Opgeslagen',
    'Saved and flushed cache' => 'Opgeslagen en cache vernieuwd',
    'Saved and sent test email to: {address}' => 'Opgeslagen en test-e-mail verzonden naar: {address}',
    'Server' => 'Server',
    'Server Timezone' => 'Server tijdzone',
    'Show introduction tour for new users' => 'Toon introductie aan nieuwe gebruikers',
    'Show user profile post form on dashboard' => 'Toon bericht verzenden van gebruikersprofiel op het dashboard',
    'Sort by creation date' => 'Sorteren op aanmaak datum',
    'Sort by update date' => 'Sorteren op update datum',
    'Test message' => 'Test bericht',
    'Theme' => 'Thema',
    'These settings refer to advanced topics of your social network.' => 'Hieronder stelt u geavanceerde onderdelen van uw site in.',
    'These settings refer to the appearance of your social network.' => 'Hieronder stelt u het uiterlijk van uw site in.',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Gebruik %url% als plaatshouder voor een URL. Het formaat dient JSON te zijn (bijv. http://www.youtube.com/oembed?url=%url%&amp;format=json)',
    'Use X-Sendfile for File Downloads' => 'Gebruik X-Sendfile voor bestand downloads',
    'Use the default swipe to show sidebar on a mobile device' => 'Gebruik de standaard veeg om de zijbalk weer te geven op een mobiel apparaat',
    'User' => 'Gebruiker',
    'User Settings' => 'Gebruikers-instellingen.',
    'Username' => 'Gebruikersnaam',
    'Username (e.g. john)' => 'Gebruikersnaam (bijvoorbeeld jan)',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'U kunt een statistieken HTML code toevoegen die aan alle pagina\'s toegevoegd zal worden.',
    'You\'re using no icon at the moment. Upload your logo now.' => 'U gebruikt momenteel geen pictogram. Upload nu uw logo.',
    'You\'re using no logo at the moment. Upload your logo now.' => 'U gebruikt momenteel geen logo. Upload nu uw logo.',
    'never' => 'nooit',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Provider Name' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Url Pattern' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/admin/messages/nl/settings.php <==
<?php

return [
    '1 month' => '1 maand',
    '1 week' => '1 week',
    '1 year' => '1 jaar',
    '2 weeks' => 'twee weken',
    '3 months' => 'drie maanden',
    '6 months' => 'zes maanden',
    '<strong>Confirm</strong> icon deletion' => '<strong>Bevestig</strong> de verwijdering van het pictogram',
    '<strong>Confirm</strong> image deletion' => '<strong>Bevestig</strong> de verwijdering van de afbeelding',
    '<strong>Maintenance</strong> Mode' => '<strong>Onderhoudsmodus</strong>',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>Waarschuwing:</strong> alle gebruikers worden onmiddellijk uitgelogd, behalve beheerders.',
    'Access Token' => 'Toegangstoken',
    'Access token is not provided yet.' => 'Toegangstoken is nog niet verstrekt.',
    'Activate' => 'Activeren',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => 'Onderhoudsmodus activeren en toegang tot het platform uitschakelen voor niet-beheerders?<br><br>',
    'Add OEmbed provider' => 'OEmbed provider toevoegen',
    'Add custom info text for maintenance mode. Displayed on the login page.' => 'Voeg aangepaste informatietekst toe voor de onderhoudsmodus. Weergegeven op de inlogpagina.',
    'Add new provider' => 'Nieuwe provider toevoegen',
    'Advanced Settings' => 'Geavanceerde Instellingen',
    'Allow Self-Signed Certificates?' => 'Sta zelfondertekende certificaten toe?',
    'Allowed file extensions' => 'Toegestane bestandsextensies',
    'Alphabetical' => 'Alfabetisch',
    'Appearance Settings' => 'Weergave instellingen',
    'Auto format based on user language - Example: {example}' => 'Automatisch indeling gebaseerd op de gebruikerstaal - Voorbeeld: {example}',
    'Back to overview' => 'Terug naar het overzicht',
    'Base URL' => 'Basis-URL',
    'Comma separated list. Leave empty to allow all.' => 'Lijst gescheiden door komma\'s. Laat leeg om alles toe te staan.',
    'Configuration (Use settings from configuration file)' => 'Configuratie (gebruik instellingen uit configuratiebestand)',
    'Could not send test email.' => 'Kan test-e-mail niet verzenden.',
    'Currently no provider active!' => 'Geen enkele provider is ingeschakeld!',
    'Currently there are {count} records in the database dating from {dating}.' => 'Momenteel zijn er {count} records in de gegevensbank vanaf {dating}.',
    'Custom DSN' => 'Aangepaste DSN',
    'DSN' => 'DSN',
    'DSN Examples:' => 'DSN-voorbeelden:',
    'Dashboard' => 'Dashboard',
    'Date input format' => 'Datum invoerformaat',
    'Deactivate' => 'Deactiveren',
    'Deactivate maintenance mode and enable all users to access the platform again?' => 'Onderhoudsmodus deactiveren en alle gebruikers weer toegang geven?',
    'Default Timezone' => 'Standaard tijdzone',
    'Default language' => 'Standaard taal',
    'Default pagination size (Entries per page)' => 'Standaard paginering grootte (Berichten per pagina)',
    'Default stream content order' => 'Standaard inhoud volgorde',
    'Delete' => 'Verwijder',
    'Dropdown space order' => 'Keuzelijst ruimte volgorde',
    'E-Mail' => 'E-mail',
    'E-Mail reply-to' => 'Antwoord naar e-mail adres',
    'E-Mail sender address' => 'E-mailadres afzender',
    'E-Mail sender name' => 'Naam van afzender',
    'E.g. http://example.com/humhub' => 'Voorbeeld http://example.com/humhub',
    'Edit OEmbed provider' => 'OEmbed provider aanpassen',
    'Embedded content requires the user\'s consent to be loaded' => 'Ingesloten inhoud vereist toestemming van de gebruiker om te worden geladen',
    'Enable maintenance mode' => 'Onderhoudsmodus inschakelen',
    'Enable user friendship system' => 'Vriendschap systeem inschakelen',
    'Enabled' => 'Ingeschakeld',
    'Enabled OEmbed providers' => 'Ingeschakelde OEmbed providers',
    'Endpoint Url' => 'Eindpunt URL',
    'Exclude media files from stream attachment list' => 'Mediabestanden niet opnemen in de lijst met berichtenbijlagen',
    'Firstname Lastname (e.g. John Doe)' => 'Voornaam Achternaam (bijvoorbeeld Jan Jansen)',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Vaste indeling (dd/mm/jjjj) - Bijvoorbeeld: {example}',
    'Friendship' => 'Vriendschap',
    'General' => 'Algemeen',
    'General Settings' => 'Algemene instellingen',
    'HTML tracking code' => 'HTML tracking code',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Hieronder past u de registratie en aanvullende gebruiker instellingen van uw website aan.',
    'Here you can configure basic settings of your social network.' => 'Hieronder verandert u de basis instellingen van uw website.',
    'Horizontal scrolling images on a mobile device' => 'Beelden horizontaal scrollen op een mobiel apparaat',
    'Icon upload' => 'Pictogram upload',
    'Last visit' => 'Laatste bezoek',
    'Logo upload' => 'Logo upload',
    'Mail Transport Type' => 'Mail transporttype',
    'Maintenance mode' => 'Onderhoudsmodus',
    'Maximum allowed age for logs.' => 'Maximaal leeftijd van logs.',
    'Maximum upload file size (in MB)' => 'Maximale bestandsgrootte (in MB\'s)',
    'Mobile appearance' => 'Mobiel uiterlijk',
    'Name of the application' => 'Naam van de applicatie',
    'No Delivery (Debug Mode, Save as file)' => 'Geen levering (foutopsporingsmodus, opslaan als bestand)',
    'No Proxy Hosts' => 'Geen Proxy Hosts',
    'Notification Settings' => 'Meldingen instellingen',
    'Old logs can significantly increase the size of your database while providing little information.' => 'Oude logs nemen veel ruimte in, maar leveren weinig informatie op.',
    'Optional. Default reply address for system emails like notifications.' => 'Optioneel. Standaard antwoordadres voor systeem-e-mails zoals meldingen.',
    'PHP (Use settings of php.ini file)' => 'PHP (gebruik de instellingen van het php.ini-bestand)',
    'PHP reported a maximum of {maxUploadSize} MB' => 'PHP meld een maximum van {maxUploadSize} MB',
    'Password' => 'Wachtwoord',
    'Port' => 'Poort',
    'Port number' => 'Poortnummer',
    'Provider Name' => 'Provider naam',
    'Regular expression by which the link match will be checked.' => 'Reguliere expressie waarmee de koppeling wordt gecontroleerd.',
    'Reported database time: {dateTime}' => 'Gemelde gegevensbanktijd: {dateTime}',
    'Save' => 'Bewaar',
    'Save & Flush Caches' => 'Bewaar &amp; vernieuw de caches',
    'Save & Test' => 'Bewaar &amp; Test',
    'Saved' => 'Opgeslagen',
    'Saved and flushed cache' => 'Opgeslagen en cache vernieuwd',
    'Saved and sent test email to: {address}' => 'Opgeslagen en test-e-mail verzonden naar: {address}',
    'Server' => 'Server',
    'Server Timezone' => 'Server tijdzone',
    'Show introduction tour for new users' => 'Toon introductie aan nieuwe gebruikers',
    'Show user profile post form on dashboard' => 'Toon bericht verzenden van gebruikersprofiel op het dashboard',
    'Sort by creation date' => 'Sorteren op aanmaak datum',
    'Sort by update date' => 'Sorteren op update datum',
    'Test message' => 'Test bericht',
    'Theme' => 'Thema',
    'These settings refer to advanced topics of your social network.' => 'Hieronder stelt u geavanceerde onderdelen van uw site in.',
    'These settings refer to the appearance of your social network.' => 'Hieronder stelt u het uiterlijk van uw site in.',
    'Url Pattern' => 'URL-patroon',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Gebruik %url% als plaatshouder voor een URL. Het formaat dient JSON te zijn (bijv. http://www.youtube.com/oembed?url=%url%&amp;format=json)',
    'Use SMTPS' => 'SMTPS gebruiken',
    'Use X-Sendfile for File Downloads' => 'Gebruik X-Sendfile voor bestand downloads',
    'User' => 'Gebruiker',
    'User Display Name' => 'Weergavenaam gebruiker',
    'User Display Name Subtitle' => 'Weergavenaam gebruiker ondertitel',
    'User Settings' => 'Gebruikers-instellingen.',
    'Username' => 'Gebruikersnaam',
    'Username (e.g. john)' => 'Gebruikersnaam (bijvoorbeeld jan)',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'U kunt een statistieken HTML code toevoegen die aan alle pagina\'s toegevoegd zal worden.',
    'You can find more configuration options here:' => 'U kunt hier meer configuratie-opties vinden:',
    'You\'re using no icon at the moment. Upload your logo now.' => 'U gebruikt momenteel geen pictogram. Upload nu uw logo.',
    'You\'re using no logo at the moment. Upload your logo now.' => 'U gebruikt momenteel geen logo. Upload nu uw logo.',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => 'bijv. 25 (voor SMTP) of 465 (voor SMTPS)',
    'e.g. localhost' => 'bijv. localhost',
    'e.g. smtps://user:pass@smtp.example.com:port' => 'bijv. smtps://gebruiker:pas@smtp.voorbeeld.com:poort',
    'never' => 'nooit',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
];
